#
# spec file for package pciutils
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname   libpci3
Name:           pciutils
Version:        3.2.1
Release:        9.4
Summary:        PCI utilities for Kernel version 2
License:        GPL-2.0+
Group:          Hardware/Other
Url:            http://atrey.karlin.mff.cuni.cz/~mj/pciutils.shtml
Source:         ftp://ftp.kernel.org/pub/software/utils/pciutils/%{name}-%{version}.tar.xz
Source2:        baselibs.conf
Patch0:         pciutils-3.2.0_update-dist.patch
Patch1:         %{name}-3.1.9_pkgconfig.patch
Patch2:         pciutils-ocloexec.patch
Patch3:         pciutils-endianh.patch
Patch4:         pciutils-3.1.7-fix-memory-leak-in-get_cache_name.patch
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libkmod)
BuildRequires:  pkgconfig(zlib)
Requires:       pciutils-ids
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# bug437293
%ifarch ppc64
Obsoletes:      pciutils-64bit
%endif

%description
lspci: This program displays detailed information about all PCI busses
and devices in the system, replacing the original /proc/pci interface.

setpci: This program allows reading from and writing to PCI device
configuration registers. For example, you can adjust the latency timers
with it.

update-pciids: This program downloads the current version of the
pci.ids file.

%package -n %{lname}
Summary:        PCI utility library
Group:          System/Libraries

%description -n %{lname}
libpci offers access to the PCI configuration space.

%package devel
Summary:        Library and Include Files of the PCI utilities
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
# bug437293
%ifarch ppc64
Obsoletes:      pciutils-devel-64bit
%endif

%description devel
This package contains the files that are necessary for software
development using the PCI utilities.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3
%patch4 -p1

%build
make %{?_smp_mflags} OPT="%{optflags} -D_GNU_SOURCE $(getconf LFS_CFLAGS) -Wall" PREFIX=%{_prefix} LIBDIR=/%{_lib} SBINDIR=/sbin STRIP="" SHARED="yes"

%install
make install PREFIX=%{buildroot}%{_prefix} SBINDIR=%{buildroot}/sbin \
             ROOT=%{buildroot}/ MANDIR=%{buildroot}/%{_mandir} STRIP="" \
	     SHARED="yes" LIBDIR=%{buildroot}/%{_lib}
mkdir -p %{buildroot}%{_includedir}/pci
cp -p lib/{pci,header,config,types}.h %{buildroot}%{_includedir}/pci/
rm -rf %{buildroot}%{_datadir}/pci.ids*
install -D -m 0644 lib/libpci.pc %{buildroot}%{_libdir}/pkgconfig/libpci.pc
ln -sf /%{_lib}/libpci.so.3 %{buildroot}%{_libdir}/libpci.so

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc README COPYING
%doc %{_mandir}/man?/*
/sbin/*

%files -n %{lname}
%defattr(-,root,root)
/%{_lib}/libpci.so.*

%files devel
%defattr(-, root, root)
%{_includedir}/pci/
%{_libdir}/*.so
%{_libdir}/pkgconfig/libpci.pc

%changelog
* Thu Mar 12 2015 tchvatal@suse.com
- pciutils-3.1.7-fix-memory-leak-in-get_cache_name.patch: Fix
  a memory leak in get_cache_name (bnc#837347)
* Mon Aug 18 2014 fcrozat@suse.com
- Add obsoletes/provides to baselibs.conf.
* Tue May 13 2014 tchvatal@suse.com
- Remove COPYING from obs it is in tarball directly
- Version bump to 3.2.1:
  * CardBus bridge capabilities are displayed.
  * PCIe L1 PM substates are decoded.
  * Various bugs were fixed in decoding of PCIe capabilities.
  * The sysfs back-end does not spit out unnecessary warnings when
    empty slots report only a partial device address. This actually
    happens on IBM pSeries.
  * Updated pci.ids to the today's snapshot of the database.
- Cleanup with spec-cleaner
* Tue Jul 30 2013 sweet_f_a@gmx.de
- Update to 3.2.0
  * On newer Linux systems, we use libkmod to look up kernel
    modules (modules.pcimap no longer exists.) To facilitate this,
    libpci is able to look up module aliases in sysfs.
  * Various minor bug fixes.
  * Updated pci.ids to the today's snapshot of the database.
- Update to 3.1.10
  * Decoding of LTR/OBFF in PCIe capabilities.
  * Various minor bug fixes.
  * Updated pci.ids to the today's snapshot of the database.
- rebase patches
- require libkmod
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Mon Dec 31 2012 crrodriguez@opensuse.org
- pciutils-endianh.patch Use the documented/optimized byteswapping
  routines from endian.h
* Sun Mar 18 2012 jengelh@medozas.de
- Shared library policy: new subpackage libpci3
* Sun Jan 29 2012 tabraham@novell.com
- Update to 3.1.9
  * Whereever we mention the PCI ID database, we now refer to
    http://pci-ids.ucw.cz/ and the sf.net site is mentioned only
    as a mirror. This includes update-pciids.
  * Decode PCIe Gen 3 speeds and link status fields
  * various minor bug fixes
  * Updated pci.ids to the 2012-01-14 snapshot of the database
- Update to 3.1.8
  * More capabilities: Transaction Processing Hints, Latency
    Tolerance Reporting. Thanks to Jesse Barnes.
  * Added BeOS and Haiku ports. Contributed by Francois Revol.
  * pciutils.pc now uses Libs.private properly.
  * When we format a name and it does not fit in the buffer, we
    truncate it instead of returning "buffer too small" instead.
    This works on all platforms with sane (i.e., C99-compatible)
    snprintf().
  * various minor bug fixes
* Mon Nov 14 2011 crrodriguez@opensuse.org
- open all file descriptors with O_CLOEXEC,specially important
  on libpci and calling apps may fork() and we end up leaking
  information to child processes.
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Thu Feb 25 2010 anicka@suse.cz
- update to 3.1.7
  * Minor improvements and bug fixes in decoding of the Virtual Channel
  capability.
  * Released as 3.1.6.
  * More capabilities decoded: Virtual Channel (except arbitration
  tables), Root Complex Link, Vendor-Specific (header only), SATA HBA.
  * All extended capabilities have their version displayed (-vv or more).
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Fri Jan 22 2010 anicka@suse.cz
- update to 1.3.5
  * Updated pci.ids to the today's snapshot of the database.
  * When scanning extended capabilities, properly mask the lowest 2 bits,
  which are currently reserved. This avoids unaligned access errors on
  broken hardware (see tests/broken-ecaps).
  * Large bar sizes are displayed in human-readable format (with units).
  * Physical slot information is displayed correctly for multi-function cards.
  * Fixed a couple of typos everywhere.
  * Library: Fixed bugs in freeing of capabilities.
  * Windows back-end compiles again.
* Tue Dec 15 2009 jengelh@medozas.de
- enable parallel building
* Thu Dec 10 2009 anicka@suse.cz
- update to 3.1.4
  * Updated pci.ids to the today's snapshot of the database.
  * Fixed memory and file descriptor leak in the dump back-end.
  * The SR-IOV capability decoder now prints the VF BAR's.
  * On request of certain company's lawyers, we now include a copy
  of the GPL with our package. It seems that the pciutils are getting
  mature if the most important bug of the month was this one ;-)
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Fri Aug 14 2009 anicka@suse.cz
- add COPYING file to fix (bnc#518238)
- fix last patch
* Mon Aug 10 2009 anicka@suse.cz
- add fclose to dump_init (bnc#529469)
* Mon Aug  3 2009 anicka@suse.cz
- update to 3.1.3
  * The VPD parser now reports unknown and vendor-defined items
  properly. It also stops on any item in unknown format,
  avoiding long output on bogus VPD data.
  * The MSI-X table size now matches the spec.
  * The Power Management capability now includes the soft reset bit.
  * Decoding of the Advanced Features capability has been added.
  * The whole package compiles on GNU/kFreeBSD again.
  * The procfs back-end is able to cope with /proc/bus/pci
  containing names with domains, which occur on sparc64 and
  possibly other architectures due to a kernel bug.
  * The sysfs back-end no longer complains when a slot address
  is missing, which happens with old versions of Linux fakephp.
  * The Device Serial Number capability is printed in the right
  byte order.
  * The MSI and MSI-X capabilities are printed in a prettier way.
  * The tree output mode (`lspci -t') shows domain numbers only
  at the root, which makes the output more compact.
  * Updated documentation on the bus mapping mode (`lspci -M').
* Thu Feb  5 2009 anicka@suse.cz
- update to 3.1.2
  * Fixed another silly bug in the command-line parser of setpci.
  * The configure script now sets LC_ALL to avoid being fooled by
  locale-dependent behavior of `tr'.
  * The command-line parser of setpci did sometimes segfault on invalid
  input.
  * The Cygwin backend now works on Windows Vista.
  * Fixed a bug in decoding of the SR-IOV capability.
  * Details of some PCIe capabilities are displayed only with -vv.
  * When a BAR is reported by the OS, but not by the device (i.e.,
  it is marked as [virtual] in lspci), the [disabled] flag is
  suppressed, because it does not make sense in such cases.
  * The source code of lspci has been split to multiple files, hopefully
  making it easier to maintain.
  * The library and lspci now know about physical slot names. So far,
  they are provided by the sysfs back-end only.
  * When a device has the VPD (Vital Product Data) capability and the
  VPD data are supplied by the OS, they are decoded and printed in the
  verbose mode. This currently works only on Linux with the sysfs
  back-end.
  * `setpci --version' now works properly.
  * `setpci --dumpregs' prints a table of all known names of
  registers and capabilities. This replaces the table of registers
  in the setpci man page.
  * The dry-run mode of setpci gives better feedback.
  * The setpci utility is now able to address registers stored in PCI
  capabilities (actually it allows a more general form of relative
  addressing).
  * The library has gained functions for working with PCI capabilities.
  * Address Translation Services capability is now decoded.
  * `lspci -k' now displays the subsystem ID, too. This makes `-k'
  show everything needed to identify the device and the available
  drivers, which was called for by many users.
  * Fixed spelling of MSI.
  * Better support for cross-compilation.
  * Fixed printing of the AER capability.
  * HT 1.02 capabilities are decoded as HT 1.03.
  * Fixed Cygwin build.
  * Fixed a minor bug in the configure script, which caused warnings
  about redefinition of symbols during compilation.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Sep 11 2008 anicka@suse.cz
- update to 3.0.1
  * Added a Cygwin port.
  * Worked around compatibility problems with various default
  settings of wget
  * Fixed printing of MSI capabilities.
  * Added decoding of several PCI-X capabilities: device/link/slot 2,
  Advanced Error Reporting, Access Control Services, Alternative
  Routing-ID, Single Root I/O Virtualization.
  * Fixed bug in filters which caused them to refuse
  vendor/device ID 0xffff.
  * Fixed several build problems: builds without PCI_USE_DNS
  on Linux and with PCI_USE_DNS on Solaris and *BSD. Static
  library mode also compiles again on old versions of GCC.
* Fri Apr 11 2008 mrueckert@suse.de
- move shared libs to /%%{_lib}
- added pciutils-3.0.0_pkgconfig.patch:
  clean up the pkgconfig file so we can include it
- package the pkgconfig file
* Thu Apr 10 2008 mrueckert@suse.de
- if we no longer provide the static lib we should at least provide
  the symlink to link against libpci
* Thu Apr 10 2008 anicka@suse.cz
- update to 3.0.0
  * The makefile system has been reworked. All configuration
  settings are now passed to the configure script in environment
  variables, allowing for easy tweaking in the top-level Makefile.
  All control knobs are now described in the README.
  * The libpci can be built as a shared library with properly
  restricted symbol exports. Use `make SHARED=yes' to enable that
  or `make SHARED=local' for a local testing build (with hardwired
  paths to the library, so that it does not need installation).
  * Support for resolving of PCI ID's using DNS together with a local
  cache of resolved entries has been added. See the `-q' and `-Q'
  options of lspci.
  * The library now has a generic system of settable parameters, which
  also include settings of the DNS resolver and cache. An `-O'
  option has been added to lspci and setpci to allow setting
  of these options.
  * Configuration of the access methods are now specified by the new
  parameter system, replacing the pci_access->method_params array.
  * Access methods now also have sensible names and help texts and it
  is possible to look up method ID by a name.
  * An `-A' switch has been added to both lspci and setpci, allowing
  to select an arbitrary access method. The `-P' switch (configure
  proc backend) has been removed as it is no longer needed
  and I do not know any its user.
  * Several source files have been split for better maintainability
  (most notably the resolving of ID's).
  * Man pages and help texts have been updated. A new man page
  `pcilib(7)' has been added and description of library options
  has been moved there.
  * When an unknown device ID is encountered, we print `Device <id>'
  instead of `Unknown device <id>'. It uses less space and it also
  should reduce the number of inexperienced users complaining that
  the device is not supported by the OS. To lookup up OS drivers,
  use the `-k' option.
  * Makefile: stripping of the binaries during installation can be
  overridden by the STRIP variable.
  * lib/types.h: We use the integer types from <stdint.h> if the
  compiler claims C99 support.
- remove strip patch
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  9 2008 anicka@suse.cz
- update to 2.2.10
  * lspci.c, setpci.c: Cleaned up the list of options.
  * lib/names.c: Fix displaying of errors reported by zlib.
  Previously, the buffer containing the error message had
  been deallocated by gzclose() before the message was printed.
  * update-pciids.sh: Added quiet mode (-q). Clean up uncompressed
  files left by previous versions of the pciutils.
  * update-pciids.man: Mention the -q switch.
  * lib/dump.c: Squashed compiler warnings about code with
  no effect (there really were surplus *'s).
* Tue Nov  6 2007 anicka@suse.cz
- update to 2.2.9
  * lspci.c: Added a new switch `-k' which requests printing
    of information on kernel drivers attached to each device
    and on kernel modules reporting the ability to handle the
    device.
  * Makefile, lib/Makefile: Moved -lz from LDFLAGS to LDLIBS.
    Also added an explicit pattern rule for linking to make sure
    that LDLIBS is used on all platforms.
  * pci.ids: Revised class codes to match Conventional PCI 3.0
    specs.
  * lspci.c: Decode the Debug port capability (per EHCI 0.96 spec).
  * lspci.c: Big code cleanup: re-arranged functions in the code,
    renamed everything related to capabilities to cap_* and
    all options except verbose to opt_*.
  * Capability loop detection introduced 2.2.7 did not work
    properly with extended capabilities. Fixed.
* Wed Oct 24 2007 anicka@suse.cz
- drop the patch backporting upstream bug in
  a machine readable output [#330533]
- fix typo in show_ext_caps in lspci
* Fri Oct  5 2007 anicka@suse.cz
- update to 2.2.7
  * lspci.c (show_caps, show_ext_caps): Detect and report loops in
    capability lists.
  * lspci.c, lib/header.h: Finished decoding of the PCI Express
    capability. The extended capabilities remain undecoded for now,
    but at least the list of them has been updated to reflect the
    current PCI Express 2.0 spec.
  * lspci.c, lib/header.h: Decode new bits of traditional registers
    as defined by PCIE / PCI-X. This includes discard timers in
    the bridge control register and INTx enable/status in device
    control/status registers.
  * Makefile, lib/Makefile: `ar' and `ranlib' can be overriden to
    allow cross-compilation.
  * lspci.c (show_ht): Added decoding of Hypertransport MSI
    mapping capability
  * tests/cap-MSI-mapping: Added a test case.
* Tue Jul  3 2007 anicka@suse.cz
- update to 2.2.6
  * Makefile: Added an "install-lib" target.
  * Makefile, lib/Makefile: Generate and install pkg-config file
  for libpci.
  * lib/i386-io-hurd.h: Rewritten for new Hurd kernels.
* Fri May  4 2007 anicka@suse.cz
- update to 2.2.5
  * pci.ids: Updated to the current snapshot of the database.
  * lspci.c (show_express): Added PCI/PCI-X to PCI-Express
    Bridge type.
  * pci.ids: Updated to the current snapshot of the database.
  * Replaced bzero() by memset() everywhere, it's better to lose
    a tiny bit of readability than maintain hacks to make it work
    on various systems.
  * lib/configure: tr on Solaris is a bit weird and it requires
    `[A-Z]' instead of `A-Z'. Fortunately, the extra brackets
    don't hurt otherwise.
  * lib/types.h, lib/configure: Solaris should use <stdint.h>
    to get precise integer types.
  * lspci.c: alloca() needs <alloca.h>.
  * lib/dump.c: Fixed a couple of bugs in the dump backend which
    caused devices with domains or with extended config space
    to be read incorrectly. Also, dumps with partial lines are
    allowed now.
  * lspci.c (scan_device): If an error occurs when reading the
    standard config header of a device, report it and ignore the
    device and return with exit code 2 at the end.
- remove noabort.diff (implemented by upstream)
* Thu Mar 29 2007 rguenther@suse.de
- add zlib-devel BuildRequires
- require zlib-devel from pciutils-devel package
* Mon Jan 29 2007 anicka@suse.cz
- change dependency from python to perl in update-pciids [#221276]
* Sat Jan 20 2007 garloff@suse.de
- Change update-pciids to download to pci.ids.d/pci.ids.dist
  and call merge-pciids if possible. [FATE 301145, bug 221276]
* Fri Oct 13 2006 aj@suse.de
- Fix to build (remove pci.ids.gz as well).
* Fri Oct 13 2006 mjancar@suse.cz
- update to 2.2.4
  * many bugfixes and cleanups
- branch separate package for pci.ids
* Mon May 22 2006 schwab@suse.de
- Don't strip binaries.
* Wed Mar 22 2006 kukuk@suse.de
- Remove pciids-suse patch (has to be fixed upstream)
* Wed Mar 22 2006 kukuk@suse.de
- Auto-Update pci.ids
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 mjancar@suse.cz
- update pci.ids (#144200)
* Fri Jan 13 2006 mjancar@suse.cz
- reintroduce "Class" printed in numeric output (#143042)
* Mon Dec 19 2005 mjancar@suse.cz
- update to 2.2.1
* Fri Aug 26 2005 mjancar@suse.cz
- add types.h to pciutils-devel (#113294)
* Wed Aug 24 2005 mjancar@suse.cz
- update to 2.1.99-test9 (#98896)
- update pci.ids (#104381)
* Mon Mar 14 2005 mjancar@suse.cz
- fix non-ascii characters in pci.ids (#72345)
* Sat Mar  5 2005 schwab@suse.de
- Fix syntax error in pci.ids.
* Tue Feb 22 2005 mjancar@suse.cz
- fix sysfs parsing (#63326)
- update pci.ids
* Fri Sep 17 2004 tcrhak@suse.cz
- updated pci.ids to the latest snapshot (fixes bug #45370)
* Thu May 27 2004 tcrhak@suse.cz
- changed "SGI IO9/IO10 Gigabit Ethernet (Copper)"
  to "SGI IO9/IO10 Gigabit Ethernet (Copper)" (bug #40175)
* Wed Apr 28 2004 tcrhak@suse.cz
- updated pci.ids
* Thu Mar  4 2004 tcrhak@suse.cz
- some pci.ids fixes:
  * changed SubDevice of Dell Inspiron 2100 internal modem (bug #32842)
  * added 1291 - Auxiliary Diva Serial Port (bug #31984)
  * added PCI IDs for InfiniBand HCAs (bug #34928)
* Tue Feb 24 2004 tcrhak@suse.cz
- added support for domains to device filter (lspci -s, setpci -s)
  (fixes bug #33382, patch sysfs-filter)
- updated pci.ids
* Sat Nov 29 2003 olh@suse.de
- use default owner for pciutils-devel files
* Wed Nov  5 2003 olh@suse.de
- remove pcimodules again, it doesnt do anything right
* Tue Oct 28 2003 olh@suse.de
- add patch for 2.6 /proc/bus/pci layout
  http://ftp.linux.org.uk/pub/linux/willy/patches/pciutils-sysfs.diff
* Wed Oct  8 2003 tcrhak@suse.cz
- added pcimodules [bug #31953]
* Mon Aug 25 2003 tcrhak@suse.cz
- updated pci.ids to the latest version from http://pciids.sourceforge.net
* Tue Feb 18 2003 tcrhak@suse.cz
- fixed NIC PCI IDs for Compaq [bug #22795],
  patch pciids.diff
- also included the diff for the latest pci.ids
  into the patch
* Wed Jan 15 2003 tcrhak@suse.cz
- fixed install paths
* Mon Jan  6 2003 tcrhak@suse.cz
- update to version 2.1.11
- updated pci.ids to the latest version from http://pciids.sourceforge.net
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Sep  6 2002 olh@suse.de
- update description of pcnet32 cards (#18892)
* Thu Aug 29 2002 tcrhak@suse.cz
- updated pci.ids to latest version from http://pciids.sourceforge.net
  this version contains entries needed by Hammer systems (bug #17549)
* Thu Aug  8 2002 olh@suse.de
- the acenic gigabit card can be either fibre or utp
  update pci.ids entry (#17502)
* Tue Jul 30 2002 tcrhak@suse.cz
- updated to version 2.1.10
- updated pci.ids to latest version from http://pciids.sourceforge.net
* Tue Mar 26 2002 tcrhak@suse.cz
- updated pci.ids to latest version from http://pciids.sourceforge.net
* Fri Jan 18 2002 tcrhak@suse.cz
- used macros %%{_lib} and %%{_libdir}
* Tue Jan  8 2002 schwab@suse.de
- Fix warnings.
* Mon Dec 17 2001 tcrhak@suse.cz
- updated pciutils to 2.1.9
- updated pci.ids to latest version from
  http://pciids.sourceforge.net/
* Wed Dec 12 2001 grimmer@suse.de
- updated pci.ids to latest version from
  http://pciids.sourceforge.net/
- added pci.ids.bz2 as a separate source file and removed
  pci.ids.add.dif (now included upstream)
* Mon Sep 24 2001 grimmer@suse.de
- added some missing PCI IDs for LSI Logic Fibre Channel
  controllers to pci.ids.add.diff
- corrected typos in pci.ids (Fiber Channel -> Fibre Channel)
- added LSI Logic Inc. to vendor ID 0x1000
* Wed Sep 19 2001 grimmer@suse.de
- added some missing PCI IDs for Compaq NICs to pci.ids.add.diff
  see [#8918] for the list
* Mon Sep 10 2001 grimmer@suse.de
- corrected some Intel NIC entries upon request from Intel
- merged pci.ids.riva.diff and the Intel changes in pci.ids.add.diff
* Mon Sep  3 2001 garloff@suse.de
- Riva TnT corrections from snbarth:
  * The name of Riva TnT 128 is Riva TnT.
  * NVidia/SGS Joint Venture (12d2) never built TNT or later.
* Wed Aug 29 2001 grimmer@suse.de
- merged pci.ids.244ac6.diff and pci.ids.add.diff into a single
  patch (again named pci.ids.add.diff) and added some more PCI IDs
  collected by Dave Jones <davej@suse.de> from various sources,
  including the current pciutils CVS tree.
- beautyfied the spec file a bit (added clean section and defattr
  in file list)
* Mon May 21 2001 poeml@suse.de
- add -devel subpackage
* Thu May 10 2001 garloff@suse.de
- Merge pci.ids from 2.4.4ac6
- bzip2 tarball
* Thu May  3 2001 garloff@suse.de
- Also don't die on failing to read data of a normal device,
  just complain loudly (and return 2 in the end)
- Updated pci.ids from linux-2.4.4 and added DFE-660.
* Wed Jan 17 2001 garloff@suse.de
- Don't die on failure to read ext. cardbus data. [#5817]
* Sun Dec 17 2000 garloff@suse.de
- Added pci.ids from linux-2.4.0-test12
- Added pci.ids floating around (lkml, RH)
- Added pci.ids for i820, ICH2/-M
* Mon Sep 18 2000 schwab@suse.de
- Add `-Wno-format' to avoid spurious compile errors.
* Thu Aug 17 2000 ro@suse.de
- cleanup srcdir
* Sun Jun 11 2000 olh@suse.de
- update to 2.1.8
* Mon Jan 24 2000 aj@suse.de
- update to 2.1.4, fix build problems with latest glibc, use patch
  for make file from Martin Mares.
* Thu Jan 20 2000 aj@suse.de
- update to 2.1.3, /usr/man -> /usr/share/man
* Tue Jan  4 2000 ro@suse.de
- update to 2.1.2
* Mon Oct 25 1999 ro@suse.de
- fixed to compile on axp
* Sat Oct 23 1999 ro@suse.de
- update to 2.1pre8 / using Buildroot
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu May 20 1999 ro@suse.de
- update to 2.0
* Wed Mar 31 1999 bs@suse.de
- don't use lx_hack for build
* Mon Feb 22 1999 ro@suse.de
- update to 1.10
* Wed Nov 25 1998 ro@suse.de
- created package, version 1.08
